pytractor provides utilities for testing Angular.js applications with selenium for Python. Selenium webdrivers are extended with functionality for dealing with Angular.js applications.

pytractor uses scripts provided by protractor (the javascript testing framework for Angular.js).
